/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import mdx from './input-checkbox.mdx';

export default {
  title: 'Product Subsystem/Components/Input Checkbox',
  parameters: {
    docs: {
      page: mdx,
    },
  },
  argTypes: {
    checked: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    required: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    invalid: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    fieldLevelHelp: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    variant: {
      control: {
        type: 'select',
      },
      options: ['base', 'label-inline', 'label-stacked', 'label-hidden'],
      defaultValue: 'base',
    },
  },
};

export const Base = (args) => `
  <slds-input-checkbox
    name="example-name"
    value="example-value"
    id="example-id"
    ${args.checked ? 'checked' : ''}
    ${args.disabled ? 'disabled' : ''}
    ${args.required ? 'required' : ''}
    ${args.invalid ? 'invalid' : ''}
    ${args.fieldLevelHelp ? 'fieldlevelhelp' : ''}
    ${args.variant ? `variant="${args.variant}"` : ''}
  >
  </slds-input-checkbox>
`;

export const Group = () => `
  <strong>Note:</strong>
  <ul>
    <li>Not an actual lightning-checkbox-group, only representing multiple lightning-input type="checkbox" on a page.</li>
    <li>"label-inline" && "label-stacked" variants change the markup of the template.</li>
    <li>"label-inline" is responsive.</li>
  </ul>
  <h2>Base</h2>
  <slds-input-checkbox
    name="example-name"
    value="example-value"
    id="example-id-1"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name"
    value="example-value"
    id="example-id-2"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name"
    value="example-value"
    id="example-id-3"
  >
  </slds-input-checkbox>


  <h2>Label Inline Variant</h2>
  <slds-input-checkbox
    name="example-name-a"
    value="example-value"
    id="example-id-4"
    variant="label-inline"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name-a"
    value="example-value"
    id="example-id-5"
    variant="label-inline"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name-a"
    value="example-value"
    id="example-id-6"
    variant="label-inline"
  >
  </slds-input-checkbox>

  <h2>Label Stacked Variant</h2>
  <slds-input-checkbox
    name="example-name-b"
    value="example-value"
    id="example-id-7"
    variant="label-stacked"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name-b"
    value="example-value"
    id="example-id-8"
    variant="label-stacked"
  >
  </slds-input-checkbox>
  <slds-input-checkbox
    name="example-name-b"
    value="example-value"
    id="example-id-9"
    variant="label-stacked"
  >
  </slds-input-checkbox>
`;
